%=========================================================================
% OSA_Prologix.m runs and plots a single scan based on current settings of 
% the ANDO AQ6317B.
% Connection is based on the COM (USB Serial Port) identified in the 
% Prologix GPIB Configurator. See here:
% http://www.ke5fx.com/gpib/readme.htm#prologix
% Ensure your OSA and Prologix devices are set to the same GPIB address.

% TIP:
% Compile to standalone application for faster performance using:
% mcc -m OSA_Prologix

% Tested using Prologix GPIB-USB Controller 6.101.
% By Priyanth Mehta (18/04/2012)
%=========================================================================

clear all
clc

ABC='A';                                %Set trace here

delete(instrfindall)
obj1 = serial('COM3');                  %Set COM Port
status=get(obj1,'status');

if strcmp(status,'closed')
    g1 = serial('COM3');
else
    fclose(obj1);
    g1 = obj1;
end

g1.Terminator = 'CR/LF';
set(g1,'InputBufferSize',10*20001);     %Creates enough space for OSA data
set(g1,'Timeout',60);                   %Code times out if it exceeds 60secs

fopen(g1);                              %Opens connection to the OSA
idn=query(g1,'*IDN?');
disp(['Connected to: ' idn(1:4) ' ' idn(6:12)])

query(g1,'SGL');                    %Runs a single scan    
                                    %A pause(n) may be needed here if OSA runs too slow 

disp('Retreiving Wavelength...')
wave=str2num(query(g1,['WDAT' ABC ]));          %Acquires wavelength data
disp('Retreiving Level...')
value=str2num(query(g1,['LDAT' ABC ]));         %Acquires level data

wavelength=wave(2:end)';                        %Crops out relevant OSA data
level=value(2:end);

fclose(g1);                                     % Close connection to GPIB
set(g1,'InputBufferSize',512);                  % Resets InputBufferSize

figure
plot(wavelength,level)